<?php
/**
* Plugin Name: Arcane tournament pay to join
* Plugin URI: https://skywarriorthemes.com/arcane
* Description: Premium tournament pay to join for Arcane theme.
* Version: 1.5
* Author: Skywarrior themes
* Author URI: https://www.skywarriorthemes.com/
*/


function arcane_register_pay_to_join_product_type() {

    /**
     * This should be in its own separate file.
     */
    if ( class_exists( 'WooCommerce' ) ) {
        class WC_Product_Pay_To_Join extends WC_Product {

            public function __construct( $product ) {

                $this->supports[]   = 'ajax_add_to_cart';
                $this->virtual = false;
                $this->manage_stock = true;

                parent::__construct( $product );

            }

            public function get_type() {
                return 'pay_to_join';
            }

        }
    }
}
add_action( 'init', 'arcane_register_pay_to_join_product_type',1 );


/**
 * Add to product type drop down.
 */
function arcane_add_pay_to_join_product( $types ){
    // Key should be exactly the same as in the class
    $types[ 'pay_to_join' ] = esc_html__( 'Pay To Join' );
    return $types;
}
add_filter( 'product_type_selector', 'arcane_add_pay_to_join_product' );


/**
 * Show pricing fields for pay_to_join product.
 */
function arcane_pay_to_join_custom_js() {
    if ( 'product' != get_post_type() ) :
        return;
    endif;
    ?><script type='text/javascript'>
        jQuery( document ).ready( function() {
            jQuery( '.pricing' ).addClass( 'show_if_pay_to_join' ).show();
            jQuery( '.inventory_options' ).addClass( 'show_if_pay_to_join' ).show();
            jQuery( '.stock_fields' ).addClass( 'show_if_pay_to_join' ).show();
            jQuery( '._manage_stock_field' ).addClass( 'show_if_pay_to_join' ).show();
        });
    </script><?php
}
add_action( 'admin_footer', 'arcane_pay_to_join_custom_js' );


/**
 * Contents of the rental options product tab.
 */
function arcane_pay_to_join_product_tab_fields() { ?>
    <div class="options_group show_if_pay_to_join"><?php

            woocommerce_wp_text_input( array(
                'id'            => '_join_tournament_id',
                'label'         => esc_html__( 'Tournament ID', 'arcane_tournament_pay_to_join' ),
                'desc_tip'      => 'true',
                'description'   => '',
                'type'          => 'text',
            ) );

            woocommerce_wp_text_input( array(
                'id'            => '_join_game_id',
                'label'         => esc_html__( 'Game ID', 'arcane_tournament_pay_to_join' ),
                'desc_tip'      => 'true',
                'description'   => esc_html__( 'Access for all tournaments with that game', 'arcane_tournament_pay_to_join' ),
                'type'          => 'text',
            ) );
            woocommerce_wp_text_input( array(
                'id'            => '_join_tournament_expire',
                'label'         => esc_html__( 'Expire days', 'arcane_tournament_pay_to_join' ),
                'desc_tip'      => 'true',
                'description'   => esc_html__( 'Add number of days before premium expires. Works for global membership and games', 'arcane_tournament_pay_to_join' ),
                'type'          => 'text',
            ) );
            woocommerce_wp_checkbox(
            array(
                'id'            => '_join_any_tournament',
                'label'         => esc_html__('Membership', 'arcane_tournament_pay_to_join' ),
                'description'   => esc_html__( 'Join any tournament', 'arcane_tournament_pay_to_join' )
                )
            );
        ?>

    </div><?php
}
add_action( 'woocommerce_product_options_general_product_data', 'arcane_pay_to_join_product_tab_fields' );


/**
 * Save the custom fields.
 */
function arcane_pay_to_join_save_fields($post_id) {

        $fields = array(
            '_join_tournament_id'       => 'int',
            '_join_game_id'     => 'int',
            '_join_tournament_expire' => 'int',
            '_join_any_tournament'      => '',
            '_stock'  => '',
            '_stock_status' => ''
        );

        foreach ( $fields as $key => $value ) {
            $value = ! empty( $_POST[ $key ] ) ? $_POST[ $key ] : '';
            switch ( $value ) {
                case 'int' :
                    $value = absint( $value );
                    break;
                case 'float' :
                    $value = floatval( $value );
                    break;
                default :
                    $value = sanitize_text_field( $value );
            }

            update_post_meta( $post_id, $key, $value );
        }

}
add_action( 'woocommerce_process_product_meta_pay_to_join', 'arcane_pay_to_join_save_fields'  );


/**
 * Hide Attributes data panel.
 */
function  arcane_pay_to_join_hide_panel ($product_data_tabs) {
        if( empty( $product_data_tabs ) ) return;

        if( isset( $product_data_tabs['shipping'] ) && isset( $product_data_tabs['shipping']['class'] ) ) {
            $product_data_tabs['shipping']['class'][] = 'hide_if_pay_to_join';
        }
        if( isset( $product_data_tabs['linked_product'] ) && isset( $product_data_tabs['linked_product']['class'] ) ) {
            $product_data_tabs['linked_product']['class'][] = 'hide_if_pay_to_join';
        }
        if( isset( $product_data_tabs['attribute'] ) && isset( $product_data_tabs['attribute']['class'] ) ) {
            $product_data_tabs['attribute']['class'][] = 'hide_if_pay_to_join';
        }

        return $product_data_tabs;
}
add_filter( 'woocommerce_product_data_tabs', 'arcane_pay_to_join_hide_panel' );


if (! function_exists( 'woocommerce_pay_to_join_add_to_cart' ) ) {
  function arcane_pay_to_join_add_to_cart() {
    wc_get_template( 'single-product/add-to-cart/simple.php' );
  }
  add_action('woocommerce_pay_to_join_add_to_cart',  'arcane_pay_to_join_add_to_cart');
}


function arcane_get_product_id_by_tournament_id( $tid ) {

    global $wpdb;

    $product_id = $wpdb->get_var( $wpdb->prepare( "SELECT post_id FROM $wpdb->postmeta WHERE meta_key='_join_tournament_id' AND meta_value='%s' LIMIT 1", $tid ) );

    return $product_id;
}

function arcane_get_product_id_by_game_id( $tid ) {

    global $wpdb;

    $product_id = $wpdb->get_results( $wpdb->prepare( "SELECT post_id FROM $wpdb->postmeta WHERE meta_key='_join_game_id' AND meta_value='%s'", $tid ) );

    return $product_id;
}

function arcane_get_product_id_for_general_membership() {

    global $wpdb;

    $product_id = $wpdb->get_results( "SELECT post_id FROM $wpdb->postmeta WHERE meta_key='_join_any_tournament' AND meta_value='yes'");

    return $product_id;
}


function arcane_get_tournament_ids_by_game( $gid ) {

    global $wpdb;
    $table_games = $wpdb->prefix."cw_games";
    $game = $wpdb->get_var( $wpdb->prepare( "SELECT title FROM $table_games WHERE id='%s'", $gid ) );
    $tids = $wpdb->get_results( $wpdb->prepare( "SELECT post_id FROM $wpdb->postmeta WHERE meta_key='tournament_game' AND meta_value='%s'", $game ) );

    $tournament_ids = array();
    foreach ($tids as $t) {
        $tournament_ids[] = $t->post_id;
    }
    if ( $tournament_ids ) return $tournament_ids;

}


/*
 * Do something after WooCommerce sets an order on completed
 */
function arcane_pay_to_join_order_completed($order_id) {

    $order = wc_get_order( $order_id );

    $items = $order->get_items();

    foreach ( $items as $item ) {
        $product = wc_get_product($item['product_id']);
        if($product->is_type('pay_to_join') && $order->customer_user) {
            $user_id = $order->customer_user;
            $pid = $product->id;

            $join_any_tournament = get_post_meta($pid, '_join_any_tournament', true);

            if($join_any_tournament == 'yes') {

                update_user_meta($user_id, 'membership_all_tournament', '1');
                update_user_meta($user_id, 'membership_all_tournament_date_added', current_time( 'timestamp', 1));

            } else {

                $join_game_id = get_post_meta($pid, '_join_game_id', true);
                if ($join_game_id) {
                    $games = array();
                    $paid_games = get_user_meta ($user_id, 'paid_games', true);
                    if($paid_games) {
                        $paid_games[] = $join_game_id;
                        $games = $paid_games;
                    } else {
                        $games[] = $join_game_id;
                    }
                    update_user_meta($user_id, 'paid_games', $games);
                    update_user_meta($user_id, 'paid_games_date_added'.$join_game_id, current_time( 'timestamp', 1));
                } else {
                    $tids = array();
                    $join_tournament_id = get_post_meta($pid, '_join_tournament_id', true);
                    if ($join_tournament_id) {
                        $paid_tournaments = get_user_meta ($user_id, 'paid_tournaments', true);
                        if($paid_tournaments) {
                            $paid_tournaments[] = $join_tournament_id;
                            $tids = $paid_tournaments;
                        } else {
                            $tids[] = $join_tournament_id;
                        }
                        update_user_meta($user_id, 'paid_tournaments', $tids);
                    }
                }

            }
        }
    }

}
add_action( 'woocommerce_order_status_completed', 'arcane_pay_to_join_order_completed' );

function arcane_check_payment_to_join($tid, $uid = 0) {
    if ($uid == 0) {
        $uid = get_current_user_id();
        if(!$uid) return;
    }

    $membership_all = get_user_meta ($uid, 'membership_all_tournament', true);
    if($membership_all == '1' ) return true;

    $paid_tournaments = get_user_meta ($uid, 'paid_tournaments', true);
    if($paid_tournaments) {
        if (in_array( $tid, $paid_tournaments)) return true;
    }

    $paid_games = get_user_meta ($uid, 'paid_games', true);
    if($paid_games) {
        $tournament_ids = array();
        foreach ($paid_games as $game) {
            $tids = arcane_get_tournament_ids_by_game($game);
            if($tids) {
                $tournament_ids = array_unique(array_merge($tids,$tournament_ids));
            }
        }
        if($tournament_ids) {
            if (in_array( $tid, $tournament_ids)) return true;
        }
    }
    return false;
}
?>