<?php

if ( ! class_exists( 'Arcane_Tournaments_Ladder' ) ) {
	class Arcane_Tournaments_Ladder {
		var $options = array();
		var $initialized = false;
		var $privateoptions = array();

		public function __construct() {
			//echo "groups";
		}

		public function GetDesc() {
			$new         = array();
			$new['slug'] = "ladder";
			$new['desc'] = esc_html__( "A Ladder is a continuous tournament. Everyone is ranked with the best players at the top of the ladder and the worst at the bottom. You are allowed to challenge any other player who is above you in the ladder (sometimes there is a restriction on how far above you, you can challenge). If you win, you take that person's place in the ladder and they and everyone between you move down one.)", "arcane_tournament_types" );
			$new['name'] = "Ladder";

			return $new;
		}


		public function GetPhaseAdminHtml() {

			if ( $this->initialized == true ) {
				//get the phase of tournament
				if ( ( ! isset( $this->privateoptions['state'] ) ) or ( $this->privateoptions['state'] == "0" ) ) {
					//we haven't EVEN set state
					//Tournament not published yet, ready to go live
					$returner = "<div id='minor-publishing-actions'><div id='save-action'><input type='submit' name='save' id='save-post' value='" . esc_html__( 'Save as Pending.', 'arcane_tournament_types' ) . "' class='button'><span class='spinner'></span></div><div id='publishing-action'><span class='spinner'></span><input name='original_publish' type='hidden' id='original_publish' value='" . esc_html__( 'Publish', 'arcane_tournament_types' ) . "'><input type='submit' name='publish' id='publish' class='button' value='" . esc_html__( 'Publish', 'arcane_tournament_types' ) . "'></div><div class='clear'></div></div>";
					//check if we just published it
					$post = get_post( $this->privateoptions['pid'] );
					if ( $post->post_status == "publish" ) {
						//post published, move to next state
						update_post_meta( $post->ID, "tournament_state", "1" );

						return false;
					}
				} else {
					if ( $this->privateoptions['state'] == "1" ) {
						$returner = "<div id='misc-publishing-actions'>" . esc_html__( 'Tournaments signups haven\'t opened yet! Click here to force them open!', 'arcane_tournament_types' ) . "</div>";

						$returner .= "<div id='major-publishing-actions'><div id='publishing-action' style='float: none; !important'><span class='spinner'></span><input name='original_publish' type='hidden' id='original_publish' value='" . esc_html__( 'Update', 'arcane_tournament_types' ) . "'><input name='save' type='submit' class='button' id='publish' value='" . esc_html__( 'Update', 'arcane_tournament_types' ) . "'></div></div>";
					}


				}

				return $returner;
			} else {
				//tournament not loaded
				return false;
			}
		}

		public function OnResultSubmit( $data ) {
			$this->RescanValues( $data['tid'] );

			return true;
		}

		public function OnTournamentStart( $tid ) {
			//schedule all matches
			$created = get_post_meta( $tid, 'games_created', true );
			//$created = 0;
			if ( $created != 1 ) {
				$competitors = get_post_meta( $tid, 'tournament_competitors', true );
				$contestants = get_post_meta( $tid, 'tournament_contestants', true );
				if ( is_array( $competitors ) and ( count( $competitors ) > 2 ) ) {
					shuffle( $competitors );
					$this->StartLadder( $tid, $competitors, $contestants );
				}
			}
		}

		private function StartLadder( $tid, $competitors, $contestants ) {
			$counter = 1;
			foreach ( $competitors as $player ) {


				$participant_cache[ $counter ]['id']                 = $player;
				$participant_cache[ $counter ]['position']           = 'unset';
				$participant_cache[ $counter ]['score']['games']     = '0';
				$participant_cache[ $counter ]['score']['victories'] = '0';
				$participant_cache[ $counter ]['score']['defeats']   = '0';
				$participant_cache[ $counter ]['score']['draws']     = '0';
				$participant_cache[ $counter ]['score']['points']    = '0';
				if ( $contestants == 'team' ) {
					$participant_cache[ $counter ]['name'] = get_the_title( $player );
					$participant_cache[ $counter ]['url']  = get_permalink( $player );
				} else {
					$user1                                 = get_user_by( 'id', $player );
					$participant_cache[ $counter ]['name'] = $user1->display_name;
					$participant_cache[ $counter ]['url']  = bp_core_get_user_domain( $player );
				}
				$counter ++;
			}
			update_post_meta( $tid, 'games_created', 1 );
			update_post_meta( $tid, 'participant_cache', $participant_cache );
			update_post_meta( $tid, 'initial_lineup', $participant_cache );
		}

		public function InitData( $tid ) {
			$options = $this->GetCreationOptions();
			$ending  = array();
			foreach ( $options as $option ) {
				if ( ( $option['type'] != "info" ) and ( $option['type'] != "heading" ) ) {
					array_push( $ending, $option );
				}
			}
			$values   = array();
			$postmeta = get_post_meta( $tid );
			if ( is_array( $ending ) ) {
				foreach ( $ending as $single ) {

					if ( isset( $postmeta[ $single['id'] ] ) ) {
						if ( $single['type'] == "checkbox" ) {
							$single['val'] = "off";
						}
						$single['val'] = $postmeta[ $single['id'] ][0];
					}
					//$single['val'] = get_post_meta($tid, $single['id'], true);
					array_push( $values, $single );
				}
			}
			$privates = array();

			if ( isset( $postmeta['tournament_state'] ) ) {
				$privates["state"] = $postmeta['tournament_state'][0];
			}
			$privates["pid"] = $tid;

			if ( isset( $postmeta['tournament_admins'] ) ) {
				$privates["admins"] = $postmeta['tournament_admins'][0];
			}
			$output = array();
			foreach ( $values as $option ) {
				//rearrange options so they have ID instead of random numerics
				$output[ $option['id'] ] = $option;
			}
			$this->options        = $output;
			$this->privateoptions = $privates;
			unset ( $single );
			unset ( $ending );
			unset ( $options );
			$this->initialized = true;
		}


		public function RescanValues( $tid ) {
			//well cause why not


			$partip_current = get_post_meta( $tid, 'participant_cache', true );
			//$partip_cache = get_post_meta($tid, 'participant_cache', true);
			$delete_competitors = get_post_meta( $tid, 'tournament_delete_competitors', true );
			$competitors        = get_post_meta( $tid, 'tournament_competitors', true );
			//$partip_cache = get_post_meta($tid, 'initial_lineup', true);
			//if (!is_array($partip_cache) OR (empty($partip_cache)) ) {
			$partip_cache = array();
			foreach ( $partip_current as $key => $current ) {
				$partip_cache[ $key ]                       = $current;
				$partip_cache[ $key ]['score']['games']     = '0';
				$partip_cache[ $key ]['score']['victories'] = '0';
				$partip_cache[ $key ]['score']['defeats']   = '0';
				$partip_cache[ $key ]['score']['draws']     = '0';
				$partip_cache[ $key ]['score']['points']    = '0';
			}
			//}

			$args  = array(
				'numberposts' => - 1,
				'post_type'   => 'matches',
				'meta_query'  => array(
					'relation' => 'AND',
					array(
						'key'   => 'tournament_id',
						'value' => $tid
					),
					array(
						'key'     => 'team1',
						'value'   => $competitors,
						'compare' => 'IN',
					),
					array(
						'key'     => 'team2',
						'value'   => $competitors,
						'compare' => 'IN',
					),
#    		array(
#				'relation' => 'OR',
#				array(
#					'key'     => 'team1',
#					'value'   => $delete_competitors,
#					'compare' => 'NOT IN',
#				),
#				array(
#					'key'     => 'team2',
#					'value'   => $delete_competitors,
#					'compare' => 'NOT IN',
#				),
#    		),
				),
				'post_status' => 'publish'
			);
			$posts = get_posts( $args );

			if ( is_array( $posts ) and ( ! empty( $posts ) ) ) {
				$matches = array();

				foreach ( $posts as $post ) {
					$meta = get_post_meta( $post->ID );

					if ( $meta['status'][0] == 'done' ) {
						//match done, add to ticker

						//ubaceno jer je uzimao samo jednu rundu kao skor
						$tickets = array_values( unserialize( $meta['tickets'][0] ) );
						foreach ( $tickets as $ticket ) {
							$matches[ $post->ID ]['t1_tickets'] += $ticket['tickets1'];
							$matches[ $post->ID ]['t2_tickets'] += $ticket['tickets2'];
						}
						//
						$meta['team1_tickets'][0]   = $tickets[0]['tickets1'];
						$meta['team2_tickets'][0]   = $tickets[0]['tickets2'];
						$matches[ $post->ID ]['id'] = $post->ID;
						$matches[ $post->ID ]['t1'] = $meta['team1'][0];
						// $matches[$post->ID]['t1_tickets'] = $meta['team1_tickets'][0];
						$matches[ $post->ID ]['t2'] = $meta['team2'][0];
						// $matches[$post->ID]['t2_tickets'] = $meta['team2_tickets'][0];
						$matches[ $post->ID ]['time'] = strtotime( $post->post_date );

						//} elseif ($meta['status'][0] == 'active') {
					} else {
						$matches[ $post->ID ]['id']     = $post->ID;
						$matches[ $post->ID ]['t1']     = $meta['team1'][0];
						$matches[ $post->ID ]['t2']     = $meta['team2'][0];
						$matches[ $post->ID ]['time']   = strtotime( $post->post_date );
						$matches[ $post->ID ]['status'] = 'tbd';
					}
				}
				ksort( $matches );

				foreach ( $matches as $match ) {

					if ( $match['status'] == 'tbd' ) {

						$newgames[ $counter ]['match_post_id']     = $match['id'];
						$newgames[ $counter ]['time']              = $match['time'];
						$t1_key                                    = $this->FindKeyById( $match['t1'], $partip_cache );
						$newgames[ $counter ]['teams'][0]['id']    = $partip_cache[ $t1_key ]['id'];
						$newgames[ $counter ]['teams'][0]['name']  = $partip_cache[ $t1_key ]['name'];
						$newgames[ $counter ]['teams'][0]['url']   = $partip_cache[ $t1_key ]['url'];
						$newgames[ $counter ]['teams'][0]['score'] = '0';
						$t2_key                                    = $this->FindKeyById( $match['t2'], $partip_cache );
						$newgames[ $counter ]['teams'][1]['id']    = $partip_cache[ $t2_key ]['id'];
						$newgames[ $counter ]['teams'][1]['name']  = $partip_cache[ $t2_key ]['name'];
						$newgames[ $counter ]['teams'][1]['url']   = $partip_cache[ $t2_key ]['url'];
						$newgames[ $counter ]['teams'][1]['score'] = '0';

					} else {

						if ( $match['t1_tickets'] > $match['t2_tickets'] ) {
							//team1 won
							$partip_cache = $this->AddAGame( $match['t1'], "win", $partip_cache );
							$partip_cache = $this->AddAGame( $match['t2'], "lose", $partip_cache );
							if ( $this->FindKeyById( $match['t1'], $partip_cache ) > $this->FindKeyById( $match['t2'], $partip_cache ) ) {
								//lower the better, swap 'em'
								$partip_cache = $this->SwapPositionsByID( $match['t2'], $match['t1'], $partip_cache );
							}
						} elseif ( $match['t1_tickets'] == $match['t2_tickets'] ) {
							//draw
							//$partip_cache = $this->AddAGame($match['t1'], "win", $partip_cache);
							//$partip_cache = $this->AddAGame($match['t2'], "lose", $partip_cache);
							$partip_cache = $this->AddAGame( $match['t1'], "draw", $partip_cache );
							$partip_cache = $this->AddAGame( $match['t2'], "draw", $partip_cache );

						} elseif ( $match['t1_tickets'] < $match['t2_tickets'] ) {
							//team2 won
							$partip_cache = $this->AddAGame( $match['t2'], "win", $partip_cache );
							$partip_cache = $this->AddAGame( $match['t1'], "lose", $partip_cache );

							if ( $this->FindKeyById( $match['t1'], $partip_cache ) < $this->FindKeyById( $match['t2'], $partip_cache ) ) {
								//lower the better, swap 'em'
								$partip_cache = $this->SwapPositionsByID( $match['t2'], $match['t1'], $partip_cache );
							}
						}
						//participants updated, just get stuff
						$newgames[ $counter ]['match_post_id'] = $match['id'];
						$newgames[ $counter ]['time']          = $match['time'];
						$newgames[ $counter ]['score']         = $match['t1_tickets'] . ":" . $match['t2_tickets'];

						$t1_key                                    = $this->FindKeyById( $match['t1'], $partip_cache );
						$newgames[ $counter ]['teams'][0]['id']    = $partip_cache[ $t1_key ]['id'];
						$newgames[ $counter ]['teams'][0]['name']  = $partip_cache[ $t1_key ]['name'];
						$newgames[ $counter ]['teams'][0]['url']   = $partip_cache[ $t1_key ]['url'];
						$newgames[ $counter ]['teams'][0]['score'] = $match['t1_tickets'];

						$t2_key                                    = $this->FindKeyById( $match['t2'], $partip_cache );
						$newgames[ $counter ]['teams'][1]['id']    = $partip_cache[ $t2_key ]['id'];
						$newgames[ $counter ]['teams'][1]['name']  = $partip_cache[ $t2_key ]['name'];
						$newgames[ $counter ]['teams'][1]['url']   = $partip_cache[ $t2_key ]['url'];
						$newgames[ $counter ]['teams'][1]['score'] = $match['t2_tickets'];
					}

					$counter ++;
				}


				if ( $delete_competitors ) {
					foreach ( $partip_cache as $k => $v ) {
						if ( in_array( $v['id'], $delete_competitors ) ) {
							unset( $partip_cache[ $k ] );
						}
					}
					$partip_cache = array_values( $partip_cache );
					array_unshift( $partip_cache, "" );
					unset( $partip_cache[0] );
				}

				update_post_meta( $tid, 'game_cache', $newgames );
				update_post_meta( $tid, 'participant_cache', $partip_cache );
				//move here

			}
		}

		private function FindKeyById( $id, $collection ) {
			if ( is_array( $collection ) and ( ! empty( $collection ) ) ) {
				foreach ( $collection as $key => $single ) {
					if ( $single['id'] == $id ) {
						return $key;
					}
				}
			}
		}

		private function SwapPositionsByID( $id1, $id2, $collection ) {
			$pos1                = $this->FindKeyById( $id1, $collection );
			$pos2                = $this->FindKeyById( $id2, $collection );
			$holder              = $collection[ $pos2 ];
			$collection[ $pos2 ] = $collection[ $pos1 ];
			$collection[ $pos1 ] = $holder;

			return $collection;
		}

		private function AddAGame( $id, $happening = "draw", $collection ) {
			$key                                  = $this->FindKeyById( $id, $collection );
			$collection[ $key ]['score']['games'] = $collection[ $key ]['score']['games'] + 1;
			if ( $happening == "win" ) {
				$collection[ $key ]['score']['victories'] = $collection[ $key ]['score']['victories'] + 1;
			} elseif ( $happening == "draw" ) {
				$collection[ $key ]['score']['draws'] = $collection[ $key ]['score']['draws'] + 1;
			} elseif ( $happening == "lose" ) {
				$collection[ $key ]['score']['defeats'] = $collection[ $key ]['score']['defeats'] + 1;
			}

			return $collection;
		}


		public function PrintStatus( $tid ) {
			$created = get_post_meta( $tid, 'games_created', true );
			$ajax_url = esc_url(admin_url( 'admin-ajax.php' ));

			if ( $created == 1 ) {
				$return = "";

				$contestants  = get_post_meta( $tid, 'tournament_contestants', true );
				$challengerID = arcane_get_my_ID_in_tournament( $tid );

				$game_stop = get_post_meta( $tid, 'game_stop', true );
				if ( $game_stop ) {
					$challengerID = false;
				}


				if ( $challengerID ) {
					$start_participants = get_post_meta( $tid, 'participant_cache', true );
					//$uid = get_current_user_id();

					foreach ( $start_participants as $k => $v ) {
						if ( $v['id'] == $challengerID ) {

							if ( isset( $v['challenges'] ) ) {

								$vchallenges = $v['challenges'];

								if ( ( isset( $vchallenges['sent'] ) ) && ( is_array( $vchallenges['sent'] ) ) ) {
									$newchallenges = array();

									foreach ( $vchallenges['sent'] as $s ) {

										if ( isset( $s['time'] ) ) {
											$current_time = strtotime( gmdate( 'Y-m-d H:i:s', ( time() + ( get_option( 'gmt_offset' ) * 3600 ) ) ) );

											if ( $s['time'] > ( $current_time - ( 24 * 60 * 60 ) ) ) {
												$newchallenges[] = $s;
											} else {
												$myid = $s['to'];
												arcane_ladder_accept_forcibly( $myid, $challengerID, $tid );
											}
										}
									}
									$vchallenges['sent'] = $newchallenges;
								}

							}
						}
					}
				}


				//$this->RescanValues($tid);
				$games            = get_post_meta( $tid, 'game_cache', true );
				$participants     = get_post_meta( $tid, 'participant_cache', true );
				$options          = arcane_get_theme_options();
				$my_position      = 0;
				$can_challenge_up = $options['ladder_max_up'];


				if ( ! $game_stop ) {
					$can_edit = arcane_TournamentsCanEdit( $tid );
					if ( $can_edit ) {


						$return .= '<div id="stop_game" class="btn">' . esc_html__( 'Stop', 'arcane_tournament_types' ) . '</div>';
						$return .= '<script> jQuery(document).ready(function($) {
                        $("#stop_game").click(function() {
                          "use strict";
                                $.ajax({
                                   type: "POST",
                                   url: "'.esc_url($ajax_url).'",
                                   data: {"action": "arcane_stop_ladder_game", tid: "' . esc_js( $tid ) . '" },
                                   success: function(data) {
                                       location.reload();
                                   }
                               });
                        });
                      });
                 </script>';
					}
				}

				if ( $challengerID ) {

					$mychallenges = [
						'sent'       => [],
						'declined'   => [],
						'received'   => [],
						'challenged' => [],
					];

					foreach ( $participants as $key => $one ) {

						if ( $one['id'] == $challengerID ) {
							$my_position = $key;
							if ( isset( $one['challenges'] ) ) {
								$mychallenges = $one['challenges'];
								$mychallenges = arcane_clean_challenges( $mychallenges, $tid );
							}
						}
					}

					$return .= '<div class="challenge_status">';


					if ( isset( $mychallenges['challenged'] ) ) {
						$challenges_left = $options['ladder_challenge_charges'] - count( $mychallenges['challenged'] );
					} else {
						$challenges_left = $options['ladder_challenge_charges'];
					}

					$declines_left       = $options['ladder_challenge_decline_charges'] - count( $mychallenges['declined'] );
					$challenges_received = count( $mychallenges['received'] );

					$return .= esc_html__( "You have", "arcane_tournament_types" ) . ' <strong>' . esc_attr( $challenges_left ) . '</strong> ' . esc_html__( "challenges and", "arcane_tournament_types" ) . ' <strong>' . esc_attr( $declines_left ) . '</strong> ' . esc_html__( "declines left. You have been challenged", "arcane_tournament_types" ) . ' <strong>' . esc_attr( $challenges_received ) . '</strong> ' . esc_html__( "times.", "arcane_tournament_types" ) . ' ';
					$return .= '</div>';

				}

				$return .= '<div class="tbbrakets">';
				$return .= '
				<div class="tbprice">
				<table class="tbgroups" cellpadding="0" cellspacing="0">
			        <tbody>
			          <tr>
			            <th>#</th>
			            <th>
		                    <img alt="team" src="' . get_template_directory_uri() . '/img/ticons/team.png">
		                    ' . esc_html__( "Team", "arcane_tournament_types" ) . '
			            </th>
			            <th>
		                    <img alt="battle" src="' . get_template_directory_uri() . '/img/ticons/battle.png">
		                     ' . esc_html__( "Battles", "arcane_tournament_types" ) . '
			            </th>
			            <th>
		                    <img alt="victory" src="' . get_template_directory_uri() . '/img/ticons/victory.png">
		                     ' . esc_html__( "Victories", "arcane_tournament_types" ) . '
			            </th>
			            <th>
		                    <img alt="defeat" src="' . get_template_directory_uri() . '/img/ticons/defeat.png">
		                     ' . esc_html__( "Defeats", "arcane_tournament_types" ) . '
			            </th>
			            <th>
		                    <img alt="draw" src="' . get_template_directory_uri() . '/img/ticons/draw.png">
		                     ' . esc_html__( "Draws", "arcane_tournament_types" ) . '
			            </th>';
				if ( $challengerID ) {
					$return .= '
							<th>
								<img alt="points" src="' . get_template_directory_uri() . '/img/ticons/points.png">
								 ' . esc_html__( "Challenger", "arcane_tournament_types" ) . '
							</th>
						</tr>';
				}


				foreach ( $participants as $position => $single ) {

					if ( isset( $single['id'] ) ) {

						$t_id = $single['id'];
						if ( $contestants == 'team' ) {
							$tp     = get_post( $t_id );
							$t_name = $tp->post_title;
						} else {
							$tp     = get_user_by( 'id', $t_id );
							$t_name = $tp->display_name;
						}

						$return .= '<tr>
				<td>' . esc_attr( $position ) . '</td>
				<td>
					<a href="' . esc_url( $single['url'] ) . '">' . esc_attr( $t_name ) . '</a>
				</td>
				<td>' . esc_attr( $single['score']['games'] ) . '</td>
				<td>' . esc_attr( $single['score']['victories'] ) . '</td>
				<td>' . esc_attr( $single['score']['defeats'] ) . '</td>
				<td>' . esc_attr( $single['score']['draws'] ) . '</td>';

						if ( ( isset( $mychallenges['received'] ) ) and ( is_array( $mychallenges['received'] ) ) ) {
							$found = false;

							foreach ( $mychallenges['received'] as $one ) {
								if ( $one['from'] == $single['id'] ) {
									$adder = '<div id="challenge_control"><div id="accept_challenge_' . esc_attr( $single['id'] ) . '" class="challenge_accept btn">' . esc_html__( 'Accept', 'arcane_tournament_types' ) . '</div>';
									if ( $declines_left > 0 ) {
										$adder .= '<div id="decline_challenge_' . esc_attr( $single['id'] ) . '" class="challenge_decline btn">' . esc_html__( 'Decline', 'arcane_tournament_types' ) . '</div>';
									}
									$adder .= '</div>';
									$found = true;
								}
							}
							if ( $found == false ) {
								$adder = '';
							}
						} else {
							$adder = "";
						}

						if ( $challengerID ) {

							if ( strlen( $adder ) > 1 ) {
								$return .= '<td>' . $adder . "</td>";
							} else {
								$found = false;

								if ( is_array( $mychallenges['sent'] ) ) {
									foreach ( $mychallenges['sent'] as $one ) {
										if ( $one['to'] == $single['id'] ) {
											$found = true;
										}
									}
								}

								if ( ! $found ) {
									$gamerunning = false;
									if ( is_array( $games ) ) {

										foreach ( $games as $game ) {

											$gt_id1 = $game['teams'][0]['id'];
											$gt_id2 = $game['teams'][1]['id'];

											if ( ( $gt_id1 == $single['id'] ) or ( $gt_id2 == $single['id'] ) ) {
												//game with ANY of teams that isn't finish
												if ( ( $game['teams'][0]['score'] == 0 ) and ( $game['teams'][1]['score'] == 0 ) and ( strlen( $game['score'] ) < 3 ) ) {
													$gamerunning = true;
												}
											}
										}
									}

									if ( $gamerunning == false ) {
										$foundCheck = false;
										if ( ( $position < $my_position ) && ( $position >= ( $my_position - $can_challenge_up ) ) ) {
											if ( $challenges_left > 0 ) {
												foreach ( $participants as $one ) {
													if ( $one['id'] == $single['id'] ) {
														$foundCheck = $one;
													}
												}
											}
										}


										if ( $foundCheck !== false ) {
											if ( ! isset( $foundCheck['challenges']['received'] ) or ( count( $foundCheck['challenges']['received'] ) == 0 ) ) {
												//no received challenges
												if ( $contestants == "team" ) {

													$teams = arcane_get_user_teams_for_challenge( get_current_user_id() );

													if ( in_array( (int) $challengerID, $teams ) ) {
														$return .= '<td><div id="challenge_' . esc_attr( $single['id'] ) . '" class="tournament_ladder_challenge btn">' . esc_html__( 'Challenge', 'arcane_tournament_types' ) . '</div></td>';
													} else {
														$return .= '<td></td>';
													}

												} else {

													$return .= '<td><div id="challenge_' . esc_attr( $single['id'] ) . '" class="tournament_ladder_challenge btn">' . esc_html__( 'Challenge', 'arcane_tournament_types' ) . '</div></td>';
												}


											} else {
												$return .= '<td></td>';
											}
										} else {
											$return .= '<td></td>';
										}
									} else {
										$return .= '<td>' . esc_html__( 'Games are still being played.', 'arcane_tournament_types' ) . '</td>';
									}

								} else {
									$return .= '<td>' . esc_html__( 'Waiting for response.', 'arcane_tournament_types' ) . '</td>';
								}
							}

						} else {
							if ( ! empty( $adder ) ) {
								$return .= '<td>' . ( $adder ) . '</td>';
							}
						}

						$return .= '</tr>';
					}
				}

				$return .= '</tbody>
			</table>
		</div>
		<div class="tbbrakets_tabs"><div class="tbbstagesw"> <ul class="nav nav-tabs " role="tablist"></ul></div>';


				if ( is_array( $games ) ) {
					$return .= '<div class="tbroundt ladder_matches"><div class="single_round_table"><h2>' . esc_html__( 'Games', 'arcane_tournament_types' ) . ' </h2><table>';
					$return .= '<tr><th><img alt="clock" src="' . get_template_directory_uri() . '/img/ticons/clock.png"> ' . esc_html__( "Match Date", "arcane_tournament_types" ) . '</th><th><img src="' . get_template_directory_uri() . '/img/ticons/team.png"> ' . esc_html__( "Team 1", "arcane_tournament_types" ) . '</th><th>' . esc_html__( "Score", "arcane_tournament_types" ) . '</th><th>' . esc_html__( "Team 2", "arcane_tournament_types" ) . ' <img src="' . get_template_directory_uri() . '/img/ticons/team.png"></th></tr>';

					foreach ( array_reverse( $games, true ) as $game ) {

						$tbd_class = '';
						if ( ! ( strlen( $game['score'] ) > 0 ) ) {
							$game['score'] = esc_html__( 'TBD', 'arcane_tournament_types' );
							$tbd_class     = 'tbd_score';
						}

						$t1_id = $game['teams'][0]['id'];
						//$t1_id = get_post_meta ($game_id, 'team1', true);
						if ( $contestants == 'team' ) {
							$t1      = get_post( $t1_id );
							$t1_name = $t1->post_title;
						} else {
							$t1      = get_user_by( 'id', $t1_id );
							$t1_name = $t1->display_name;
						}
						$t2_id = $game['teams'][1]['id'];
						//$t2_id = get_post_meta ($game_id, 'team2', true);
						if ( $contestants == 'team' ) {
							$t2      = get_post( $t2_id );
							$t2_name = $t2->post_title;
						} else {
							$t2      = get_user_by( 'id', $t2_id );
							$t2_name = $t2->display_name;
						}

						/*izbaceno jer ne pise tbd vec pokazuje skor*/
						/*
					   $post_meta = get_post_meta($game_id);
					   if(!empty($post_meta['team1_tickets'][0]) or !empty($post_meta['team2_tickets'][0]))
					   $game['score'] = $post_meta['team1_tickets'][0].':'.$post_meta['team2_tickets'][0];
					*/

						$return .= '<tr>
		                  <td>' . date_i18n( get_option( 'date_format' ) . " " . get_option( 'time_format' ), $game['time'] ) . '
		                  <td><a href="' . esc_url( $game['teams'][0]['url'] ) . '"  target="_blank">' . esc_attr( $t1_name ) . '</a></td>
		                  <td class="gscore"><a class="' . esc_attr( $tbd_class ) . '"  href="' . get_permalink( $game['match_post_id'] ) . '" target="_blank">' . esc_attr( $game['score'] ) . '</a></td>
		                  <td><a href="' . esc_url( $game['teams'][1]['url'] ) . '"  target="_blank">' . esc_attr( $t2_name ) . '</a></td>
		                  </tr>';

					}

				}
				$return .= '</table></div></div>';

				$return  .= '<script>
				jQuery(document).ready(function($) {

				    let ladderChallenge = $(".tournament_ladder_challenge");
                    ladderChallenge.one("click", function() {

                        if($(this).hasClass("disabled")) {
                            return false;
                        } else {
                            $(this).addClass("disabled");
                        }
                        $.ajax({
                           type: "POST",
                           url: "'.esc_url($ajax_url).'",
                           data: {"action": "arcane_send_challenge", "target_id": $(this).attr("id"), "myid": "' . esc_js( $challengerID ) . '", tid: "' . esc_js( $tid ) . '" },
                           success: function(data) {
                             location.reload();
                           }
                       });
                    });
					
					let acceptChallenge = $(".challenge_accept");
                    acceptChallenge.one("click", function() {
   
                        if($(this).hasClass("disabled")) {
                            return false;
                        } else {
                            $(this).addClass("disabled");
                        }
                        $.ajax({
                           type: "POST",
                           url: "'.esc_url($ajax_url).'",
                           data: {"action": "arcane_ladder_accept", "target_id": $(this).attr("id"), "myid": "' . esc_js( $challengerID ) . '", tid: "' . esc_js( $tid ) . '" },
                           success: function(data) {
                              location.reload();
                           }
                       });
                    });
				
					let declineChallenge = $(".challenge_decline");
                    declineChallenge.one("click", function() {

                        if($(this).hasClass("disabled")) {
                            return false;
                        } else {
                            $(this).addClass("disabled");
                        }
                        $.ajax({
                           type: "POST",
                           url: "'.esc_url($ajax_url).'",
                           data: {"action": "arcane_ladder_decline", "target_id": $(this).attr("id"), "myid": "' . esc_js( $challengerID ) . '", tid: "' . esc_js( $tid ) . '" },
                           success: function(data) {
                              location.reload();
                           }
                       });
                    });

                  });
             </script>';

				$return .= '</div></div>';

				return $return;
			} else {
				return false;
			}

		}

		public function GetCreationOptions() {
			//kindoffunny but let's create options for ourselves
			$options = array(
				array(
					"name" => esc_html__( "Dates", 'arcane_tournament_types' ),
					"type" => "heading"
				),
				array(
					"name" => esc_html__( "Dates", 'arcane_tournament_types' ),
					"type" => "info"
				),
				array(
					"name" => esc_html__( "Tournament starts", 'arcane_tournament_types' ),
					"desc" => esc_html__( "Date when tournament starts", 'arcane_tournament_types' ),
					"id"   => "tournament_starts",
					"type" => "date"
				),
				array(
					"name" => esc_html__( "Participants and games", 'arcane_tournament_types' ),
					"type" => "heading"
				),
				array(
					"name" => esc_html__( "Participant and games data", 'arcane_tournament_types' ),
					"type" => "info"
				),
				array(
					"name"    => esc_html__( "Participant types", 'arcane_tournament_types' ),
					"desc"    => esc_html__( "Single user or a team", 'arcane_tournament_types' ),
					"id"      => "participant_type",
					"type"    => "select",
					"options" => array( "user", "team" )
				),
				array(
					"name" => esc_html__( "Participants", 'arcane_tournament_types' ),
					"desc" => esc_html__( "Minimal number of participants needed for tournament", 'arcane_tournament_types' ),
					"id"   => "num_participants",
					"type" => "number"
				),
				array(
					"name"    => esc_html__( "Games number", 'arcane_tournament_types' ),
					"desc"    => esc_html__( "Choose how many games each team plays (Best of X games)", 'arcane_tournament_types' ),
					"id"      => "games_number",
					"type"    => "select",
					"options" => array( "BO1", "BO2", "BO3", "BO4", "BO5" )
				),

				array(
					"name" => esc_html__( "Games played", 'arcane_tournament_types' ),
					"desc" => esc_html__( "Schedule a game every X days (1 means daily, 7 means one weekly)", 'arcane_tournament_types' ),
					"id"   => "schedule_every_x_days",
					"type" => "number"
				),
			);

			return $options;
		}
	}
}

array_push( $formats, 'Arcane_Tournaments_Ladder' );